@@ -6,9 +6,9 @@ Type annotations for mediatailor service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_mediatailor.literals import AccessType
+    from mypy_boto3_mediatailor.literals import AccessTypeType
 
-    data: AccessType = "S3_SIGV4"
+    data: AccessTypeType = "S3_SIGV4"
     ```
 """
 import sys
@@ -20,32 +20,32 @@ else:
 
 
 __all__ = (
-    "AccessType",
-    "ChannelState",
+    "AccessTypeType",
+    "ChannelStateType",
     "GetChannelSchedulePaginatorName",
     "ListChannelsPaginatorName",
     "ListPlaybackConfigurationsPaginatorName",
     "ListSourceLocationsPaginatorName",
     "ListVodSourcesPaginatorName",
-    "MessageType",
-    "Mode",
-    "OriginManifestType",
-    "PlaybackMode",
-    "RelativePosition",
+    "MessageTypeType",
+    "ModeType",
+    "OriginManifestTypeType",
+    "PlaybackModeType",
+    "RelativePositionType",
     "TypeType",
 )
 
 
-AccessType = Literal["S3_SIGV4"]
-ChannelState = Literal["RUNNING", "STOPPED"]
+AccessTypeType = Literal["S3_SIGV4"]
+ChannelStateType = Literal["RUNNING", "STOPPED"]
 GetChannelSchedulePaginatorName = Literal["get_channel_schedule"]
 ListChannelsPaginatorName = Literal["list_channels"]
 ListPlaybackConfigurationsPaginatorName = Literal["list_playback_configurations"]
 ListSourceLocationsPaginatorName = Literal["list_source_locations"]
 ListVodSourcesPaginatorName = Literal["list_vod_sources"]
-MessageType = Literal["SPLICE_INSERT"]
-Mode = Literal["BEHIND_LIVE_EDGE", "OFF"]
-OriginManifestType = Literal["MULTI_PERIOD", "SINGLE_PERIOD"]
-PlaybackMode = Literal["LOOP"]
-RelativePosition = Literal["AFTER_PROGRAM", "BEFORE_PROGRAM"]
+MessageTypeType = Literal["SPLICE_INSERT"]
+ModeType = Literal["BEHIND_LIVE_EDGE", "OFF"]
+OriginManifestTypeType = Literal["MULTI_PERIOD", "SINGLE_PERIOD"]
+PlaybackModeType = Literal["LOOP"]
+RelativePositionType = Literal["AFTER_PROGRAM", "BEFORE_PROGRAM"]
 TypeType = Literal["DASH", "HLS"]
